encoding: Improving structure and documentation of block helpers

This commit add several new helpers to simplify operations with
std::string:

- prependStringBlock
- makeStringBlock
- readString

The following functions are deprecated and their replacements:

- nonNegativeIntegerBlock (use makeNonNegativeIntegerBlock)
- prependBooleanBlock (use prependEmptyBlock)
- booleanBlock (use makeEmptyBlock)
- dataBlock (use makeBinaryBlock)
- nestedBlock (use makeNestedBlock)

Change-Id: Ic595ae64fc9c80c2c04e5fde1d8812e8b9debd60
Refs: #2951
diff --git a/src/data.hpp b/src/data.hpp
index b12061b..b5e1c02 100644
--- a/src/data.hpp
+++ b/src/data.hpp
@@ -91,7 +91,7 @@
   /**
    * @brief Fast encoding or block size estimation
    *
    * @param block                   EncodingEstimator or EncodingBuffer instance
    * @param wantUnsignedPortionOnly Request only unsigned portion to be encoded in block.
    *                                If true, only Name, MetaInfo, Content, and SignatureInfo
    *                                blocks will be encoded into the block. Note that there
@@ -99,7 +99,7 @@
    */
   template<encoding::Tag TAG>
   size_t
-  wireEncode(EncodingImpl<TAG>& block, bool wantUnsignedPortionOnly = false) const;
+  wireEncode(EncodingImpl<TAG>& encoder, bool wantUnsignedPortionOnly = false) const;
 
   /**
    * @brief Encode to a wire format
@@ -91,7 +91,7 @@
    * @brief Fast encoding or block size estimation
    *
-   * @param block                   EncodingEstimator or EncodingBuffer instance
+   * @param encoder                 EncodingEstimator or EncodingBuffer instance
    * @param wantUnsignedPortionOnly Request only unsigned portion to be encoded in block.
    *                                If true, only Name, MetaInfo, Content, and SignatureInfo